pub struct SignRelation {
pub from: Pubkey,
pub provider: Pubkey,
pub tree: Pubkey,
pub tree_controller: Pubkey,
pub payer: Pubkey,
pub ac_program: Pubkey,
pub noop_program: Pubkey,
pub graph_program: Pubkey,
}Expand description
Generated client accounts for SignRelation.
Fields
from: Pubkeyprovider: Pubkeytree: Pubkeytree_controller: Pubkeypayer: Pubkeyac_program: Pubkeynoop_program: Pubkeygraph_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for SignRelationwhere
Pubkey: BorshSerialize,
impl BorshSerialize for SignRelationwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for SignRelation
impl ToAccountMetas for SignRelation
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for SignRelation
impl RefUnwindSafe for SignRelation
impl Send for SignRelation
impl Sync for SignRelation
impl Unpin for SignRelation
impl UnwindSafe for SignRelation